"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockSimpleHttpClient = void 0;
class MockSimpleHttpClient {
    constructor() {
        this.responses = {};
        this._requests = [];
    }
    setNextResponse(key, response) {
        if (!this.responses.hasOwnProperty(key)) {
            this.responses[key] = [response];
        }
        else {
            this.responses[key].push(response);
        }
    }
    request(config) {
        return __awaiter(this, void 0, void 0, function* () {
            // Copy config object and add method, if necessary
            config = Object.assign({}, config);
            if (typeof config.method === "undefined") {
                config.method = "GET";
            }
            // Derive key
            const key = `${config.method || ""} ${config.baseURL || ""}${config.url || ""}`;
            // Throw if no response set
            if (!this.responses.hasOwnProperty(key) || this.responses[key].length === 0) {
                throw new Error(`Received HTTP request for ${key}, but there is no response configured for that ` +
                    `request. Use 'setNextResponse("${key}", yourResponse)' to set a response. (Note that ` +
                    `'yourResponse' should be either a SimpleHttpResponseInterface or an ErrnoException.)` +
                    `\n\nRequest Config:\n\n${JSON.stringify(config, null, 2)}`);
            }
            this._requests.push(config);
            // Otherwise, throw or return according to set response
            const res = this.responses[key].shift();
            if (typeof res.stack !== "undefined") {
                throw res;
            }
            else {
                return res;
            }
        });
    }
    resetRequestLog() {
        this._requests = [];
    }
    get requestLog() {
        return this._requests;
    }
}
exports.MockSimpleHttpClient = MockSimpleHttpClient;
