"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockSimpleLogger = void 0;
class MockSimpleLogger {
    constructor(opts = {}) {
        this._loggedMessages = [];
        if (!opts) {
            opts = {};
        }
        this.opts = opts;
    }
    setOpt(opt, val) {
        this.opts[opt] = val;
    }
    get messages() {
        return this._loggedMessages;
    }
    match(re) {
        for (let msg of this._loggedMessages) {
            if (msg.match(re)) {
                return true;
            }
        }
        return false;
    }
    clear() {
        this._loggedMessages = [];
        return this;
    }
    emergency(message, ...meta) {
        return this.log("emergency", message, meta);
    }
    critical(message, ...meta) {
        return this.log("critical", message, meta);
    }
    alert(message, ...meta) {
        return this.log("alert", message, meta);
    }
    error(message, ...meta) {
        return this.log("error", message, meta);
    }
    warning(message, ...meta) {
        return this.log("warning", message, meta);
    }
    notice(message, ...meta) {
        return this.log("notice", message, meta);
    }
    info(message, ...meta) {
        return this.log("info", message, meta);
    }
    debug(message, ...meta) {
        return this.log("debug", message, meta);
    }
    log(level, message, ...meta) {
        this._loggedMessages.push(`${level}: ${message}`);
        if (this.opts.outputMessages) {
            console.log(`${level}: ${message}` + (meta.length > 0 ? JSON.stringify(meta) : ""));
        }
        return this;
    }
}
exports.MockSimpleLogger = MockSimpleLogger;
