"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockSimpleSqlDb = exports.md5 = void 0;
const md5_1 = require("ts-md5/dist/md5");
exports.md5 = function (str) {
    return md5_1.Md5.hashStr(str).toString();
};
const isResponse = function (val) {
    return typeof val.rows !== "undefined";
};
class MockSimpleSqlDb {
    constructor(config) {
        this.closed = false;
        this.config = {
            throwOnClose: false
        };
        this.queryMockResultQueue = {};
        if (typeof config !== undefined) {
            this.config = Object.assign({}, this.config, config);
        }
    }
    /**
     * If an exception is passed, it is thrown when the query is called. Otherwise, the given response is returned
     */
    setQueryResult(hashOrQuery, result) {
        if (typeof this.queryMockResultQueue[hashOrQuery] === "undefined") {
            this.queryMockResultQueue[hashOrQuery] = [];
        }
        this.queryMockResultQueue[hashOrQuery].push(result);
    }
    query(query, params) {
        if (this.closed) {
            throw new Error("The 'close' method was previously called on this database connection, so no further queries may be made. Pass '{ throwOnClose: true }' to the constructor of this SimpleMockDb to see when the 'close' method was called.");
        }
        const hash = exports.md5(query);
        const queueKey = typeof this.queryMockResultQueue[hash] !== "undefined" ? hash : query;
        if (typeof this.queryMockResultQueue[queueKey] === "undefined" ||
            this.queryMockResultQueue[queueKey].length === 0) {
            const msg = "This is a mock database. You must manually set the result you'd like to receive from each query using the 'setQueryResult' method. You should pass either the exact query string (below) or the hash of the query string ('" +
                hash +
                "') as the first argument of that function, then an array containing result objects as the second method.\n\nQuery:\n\n" +
                query +
                "\n\nwith params:\n\n" +
                JSON.stringify(params, null, 2);
            // Because of complexities of async functions and throwing errors, there is NO WAY TO CATCH AND DISPLAY THIS ERROR.
            // Thus, we must compromise and log the message as well as throw.
            console.log(msg);
            throw new Error(msg);
        }
        const t = this;
        return new Promise(function (resolve, reject) {
            const res = t.queryMockResultQueue[queueKey].shift();
            if (isResponse(res)) {
                resolve(res);
            }
            else {
                reject(res);
            }
        });
    }
    close() {
        if (this.config.throwOnClose) {
            throw new Error("The 'close' method was just called on this database connection, and the 'throwOnClose' config option was set to 'true'.");
        }
        this.closed = true;
    }
}
exports.MockSimpleSqlDb = MockSimpleSqlDb;
